"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.replacePath = exports.extractImportPaths = exports.unknownImportPaths = exports.computeSearchRegExp = exports.getTsConfig = void 0;
const node_path_1 = require("node:path");
const node_fs_1 = require("node:fs");
const typescript_1 = __importDefault(require("typescript"));
function getTsConfig(cwd, path) {
    const resolvedTsConfigPath = (0, node_path_1.resolve)(cwd, path);
    const { config: json, error } = typescript_1.default.readConfigFile(resolvedTsConfigPath, (path) => (0, node_fs_1.readFileSync)(path).toString('utf-8'));
    if (error) {
        throw Object.assign(new Error(typescript_1.default.formatDiagnostic(error, {
            getCanonicalFileName: (path) => path,
            getCurrentDirectory: () => cwd,
            getNewLine: () => '\n',
        })), { json });
    }
    return typescript_1.default.parseJsonConfigFileContent(json, typescript_1.default.sys, cwd);
}
exports.getTsConfig = getTsConfig;
function computeSearchRegExp(paths) {
    return new RegExp(`(${Object.keys(paths)
        .map((p) => p.replace('*', '(.*)'))
        .join('|')})`);
}
exports.computeSearchRegExp = computeSearchRegExp;
exports.unknownImportPaths = new Set();
function extractImportPaths(node, paths = new Set()) {
    if (typescript_1.default.isImportDeclaration(node) &&
        typescript_1.default.isStringLiteral(node.moduleSpecifier)) {
        paths.add(node.moduleSpecifier.text);
    }
    else if (typescript_1.default.isExportDeclaration(node) &&
        node.moduleSpecifier &&
        typescript_1.default.isStringLiteral(node.moduleSpecifier)) {
        paths.add(node.moduleSpecifier.text);
    }
    else if (typescript_1.default.isCallExpression(node) &&
        typescript_1.default.isIdentifier(node.expression) &&
        node.expression.text === 'require' &&
        node.arguments.length >= 1 &&
        typescript_1.default.isStringLiteral(node.arguments[0])) {
        paths.add(node.arguments[0].text);
    }
    else if (typescript_1.default.isAwaitExpression(node) &&
        typescript_1.default.isImportCall(node.expression) &&
        node.expression.arguments.length >= 1 &&
        typescript_1.default.isStringLiteral(node.expression.arguments[0])) {
        paths.add(node.expression.arguments[0].text);
    }
    typescript_1.default.forEachChild(node, (childNode) => {
        extractImportPaths(childNode, paths);
    });
    return paths;
}
exports.extractImportPaths = extractImportPaths;
function replacePath(content, mapping) {
    const regBase = Object.keys(mapping).join('|');
    const regEx = new RegExp(`(["'])(${regBase})\\1`, `g`);
    return content.replace(regEx, (match, quote, path) => {
        const resolvedPath = mapping[path];
        if (!resolvedPath) {
            throw new Error(`Unable to resolve "${path}"`);
        }
        return `${quote}${resolvedPath}${quote}`;
    });
}
exports.replacePath = replacePath;
//# sourceMappingURL=tools.js.map